<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

if ( ! function_exists( 'greatnews_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Greatnews Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function greatnews_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'greatnews_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'greatnews_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Greatnews Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
function greatnews_pro_is_loader_enable( $control ) {
	return $control->manager->get_setting( 'greatnews_pro_theme_options[loader_enable]' )->value();
}
endif;

if ( ! function_exists( 'greatnews_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Greatnews Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
function greatnews_pro_is_pagination_enable( $control ) {
	return $control->manager->get_setting( 'greatnews_pro_theme_options[pagination_enable]' )->value();
}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[topbar_section_enable]' )->value() );
}

/**
 * Check if breakingnews section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_breakingnews_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[breakingnews_section_enable]' )->value() );
}

/**
 * Check if breakingnews section content type is category.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_breakingnews_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[breakingnews_content_type]' )->value();
	return greatnews_pro_is_breakingnews_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if breakingnews section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_breakingnews_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[breakingnews_content_type]' )->value();
	return greatnews_pro_is_breakingnews_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if breakingnews section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_breakingnews_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[breakingnews_content_type]' )->value();
	return greatnews_pro_is_breakingnews_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if hero section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_hero_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[hero_section_enable]' )->value() );
}

/**
 * Check if hero section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_hero_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[hero_content_type]' )->value();
	return greatnews_pro_is_hero_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if hero section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_hero_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[hero_content_type]' )->value();
	return greatnews_pro_is_hero_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if hero section content type is category.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_hero_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[hero_content_type]' )->value();
	return greatnews_pro_is_hero_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if thumbnail section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_thumbnail_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[thumbnail_section_enable]' )->value() );
}

/**
 * Check if thumbnail section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_thumbnail_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[thumbnail_content_type]' )->value();
	return greatnews_pro_is_thumbnail_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if thumbnail section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_thumbnail_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[thumbnail_content_type]' )->value();
	return greatnews_pro_is_thumbnail_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if thumbnail section content type is category.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_thumbnail_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[thumbnail_content_type]' )->value();
	return greatnews_pro_is_thumbnail_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if slider section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[slider_content_type]' )->value();
	return greatnews_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[slider_content_type]' )->value();
	return greatnews_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[slider_content_type]' )->value();
	return greatnews_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if trending section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_trending_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[trending_section_enable]' )->value() );
}

/**
 * Check if slider section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_trending_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[trending_news_content_type]' )->value();
	return greatnews_pro_is_trending_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_trending_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[trending_news_content_type]' )->value();
	return greatnews_pro_is_trending_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is custom.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_trending_news_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[trending_news_content_type]' )->value();
	return greatnews_pro_is_trending_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if most viewed section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_most_viewed_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[most_viewed_section_enable]' )->value() );
}

/**
 * Check if most viewed section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_most_viewed_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[most_viewed_content_type]' )->value();
	return greatnews_pro_is_most_viewed_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if most viewed section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_most_viewed_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[most_viewed_content_type]' )->value();
	return greatnews_pro_is_most_viewed_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if most viewed section content type is category.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_most_viewed_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[most_viewed_content_type]' )->value();
	return greatnews_pro_is_most_viewed_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if most viewed section content type is recent.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_most_viewed_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[most_viewed_content_type]' )->value();
	return greatnews_pro_is_most_viewed_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if featured section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_media_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[media_news_section_enable]' )->value() );
}
/**
 * Check if reading section is enabled.
 *
 * @since Greatnews Book Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_reading_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[reading_section_enable]' )->value() );
}

/**
 * Check if reading section content type is category.
 *
 * @since Greatnews Book Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_reading_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[reading_content_type]' )->value();
	return greatnews_pro_is_reading_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if reading section content type is page.
 *
 * @since Greatnews Book Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_reading_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[reading_content_type]' )->value();
	return greatnews_pro_is_reading_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if reading section content type is post.
 *
 * @since Greatnews Book Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_reading_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[reading_content_type]' )->value();
	return greatnews_pro_is_reading_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if reading section content type is category.
 *
 * @since Greatnews Book Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_reading_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[reading_post_content_type]' )->value();
	return greatnews_pro_is_reading_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if reading_post section content type is page.
 *
 * @since Greatnews Book Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_reading_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[reading_post_content_type]' )->value();
	return greatnews_pro_is_reading_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if reading_post section content type is post.
 *
 * @since Greatnews Book Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_reading_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[reading_post_content_type]' )->value();
	return greatnews_pro_is_reading_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if single_column section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_single_column_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[single_column_section_enable]' )->value() );
}

/**
 * Check if single_column section content type is category.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_single_column_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[single_column_content_type]' )->value();
	return greatnews_pro_is_single_column_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if single_column section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_single_column_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[single_column_content_type]' )->value();
	return greatnews_pro_is_single_column_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if single_column section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_single_column_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[single_column_content_type]' )->value();
	return greatnews_pro_is_single_column_section_enable( $control ) && ( 'post' == $content_type );
}


/**
 * Check if blog section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[blog_content_type]' )->value();
	return greatnews_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[blog_content_type]' )->value();
	return greatnews_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[blog_content_type]' )->value();
	return greatnews_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[blog_content_type]' )->value();
	return greatnews_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/*service section*/
	
	/**
 * Check if service section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[service_content_type]' )->value();
	return greatnews_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[service_content_type]' )->value();
	return greatnews_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[service_content_type]' )->value();
	return greatnews_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/*end service section*/

/*recent product*/

/**
 * Check if product section is enabled.
 *
 * @since Greatnews Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if product section content type is product.
 *
 * @since Greatnews Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[product_content_type]' )->value();
	return greatnews_pro_is_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if product section content type is product category.
 *
 * @since Greatnews Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[product_content_type]' )->value();
	return greatnews_pro_is_product_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*end recent product*/


function greatnews_pro_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[subscription_section_enable]' )->value() );
}

//featured section
function greatnews_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[featured_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/*about us section*/

/**
 * Check if about section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[about_content_type]' )->value();
	return greatnews_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[about_content_type]' )->value();
	return greatnews_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[about_content_type]' )->value();
	return greatnews_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/*end about us section*/

/**
 * Check if counter section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[counter_section_enable]' )->value() );
}

/*course section*/

/**
 * Check if course section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_course_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[course_section_enable]' )->value() );
}

/**
 * Check if course section content type is category.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_course_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[course_content_type]' )->value();
	return greatnews_pro_is_course_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if course section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_course_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[course_content_type]' )->value();
	return greatnews_pro_is_course_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if course section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_course_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[course_content_type]' )->value();
	return greatnews_pro_is_course_section_enable( $control ) && ( 'post' == $content_type );
}

/*end course section*/

/*team section*/

/**
 * Check if team section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[team_content_type]' )->value();
	return greatnews_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is custom.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_team_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[team_content_type]' )->value();
	return greatnews_pro_is_team_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if team section seperator.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_team_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[team_content_type]' )->value();
	return greatnews_pro_is_team_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if team section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[team_content_type]' )->value();
	return greatnews_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[team_content_type]' )->value();
	return greatnews_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/*end team section*/


/*Popular Destination*/

/**
 * Check if popular destination section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[popular_destination_section_enable]' )->value() );
}

/**
 * Check if popular destination section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[popular_destination_content_type]' )->value();
	return greatnews_pro_is_popular_destination_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular destination section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[popular_destination_content_type]' )->value();
	return greatnews_pro_is_popular_destination_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular destination section content type is trip.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[popular_destination_content_type]' )->value();
	return greatnews_pro_is_popular_destination_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if popular destination section content type is category.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[popular_destination_content_type]' )->value();
	return greatnews_pro_is_popular_destination_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular destination section content type is trip types.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_destination_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[popular_destination_content_type]' )->value();
	return greatnews_pro_is_popular_destination_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if popular destination section content type is destination.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_destination_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[popular_destination_content_type]' )->value();
	return greatnews_pro_is_popular_destination_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if popular destination section content type is activity.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_destination_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[popular_destination_content_type]' )->value();
	return greatnews_pro_is_popular_destination_section_enable( $control ) && ( 'activity' == $content_type );
}

/*End Popular Destination*/

/*Popular Tour*/

/**
 * Check if popular tours section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_tours_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[popular_tours_section_enable]' )->value() );
}

/**
 * Check if popular tours section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_tours_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[popular_tours_content_type]' )->value();
	return greatnews_pro_is_popular_tours_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular tours section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_tours_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[popular_tours_content_type]' )->value();
	return greatnews_pro_is_popular_tours_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular tours section content type is trip.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_tours_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[popular_tours_content_type]' )->value();
	return greatnews_pro_is_popular_tours_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if popular tours section content type is category.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_tours_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[popular_tours_content_type]' )->value();
	return greatnews_pro_is_popular_tours_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular tours section content type is trip types.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_tours_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[popular_tours_content_type]' )->value();
	return greatnews_pro_is_popular_tours_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if popular tours section content type is tours.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_tours_section_content_tours_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[popular_tours_content_type]' )->value();
	return greatnews_pro_is_popular_tours_section_enable( $control ) && ( 'tours' == $content_type );
}

/**
 * Check if popular tours section content type is activity.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_popular_tours_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[popular_tours_content_type]' )->value();
	return greatnews_pro_is_popular_tours_section_enable( $control ) && ( 'activity' == $content_type );
}

/*End Popular Tour*/

/*cta*/
/**
 * Check if video section is enabled.
 *
 * @since greatnews_pro_ 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since greatnews_pro_ 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[cta_content_type]' )->value();
	return greatnews_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since greatnews_pro_ 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[cta_content_type]' )->value();
	return greatnews_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since greatnews_pro_ 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[cta_content_type]' )->value();
	return greatnews_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}
/*end cta*/

/*features section*/
	
	/**
 * Check if features section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_features_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[features_section_enable]' )->value() );
}

/**
 * Check if features section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_features_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[features_content_type]' )->value();
	return greatnews_pro_is_features_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if features section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_features_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[features_content_type]' )->value();
	return greatnews_pro_is_features_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if features section content type is category.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_features_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[features_content_type]' )->value();
	return greatnews_pro_is_features_section_enable( $control ) && ( 'category' == $content_type );
}

/*end features section*/

/*medical reason*/

/**
 * Check if reason section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_reason_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[reason_section_enable]' )->value() );
}

/**
 * Check if reason section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_reason_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[reason_content_type]' )->value();
	return greatnews_pro_is_reason_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if reason section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_reason_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[reason_content_type]' )->value();
	return greatnews_pro_is_reason_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if reason section content type is custom.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_reason_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[reason_content_type]' )->value();
	return greatnews_pro_is_reason_section_enable( $control ) && ( 'custom' == $content_type );
}

/*end medical reason*/

/**
 * Check if video section is enabled.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_video_section_enable( $control ) {
	return ( $control->manager->get_setting( 'greatnews_pro_theme_options[video_section_enable]' )->value() );
}

/**
 * Check if video section content type is post.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_video_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[video_content_type]' )->value();
	return greatnews_pro_is_video_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if video section content type is page.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_video_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[video_content_type]' )->value();
	return greatnews_pro_is_video_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if video section content type is custom.
 *
 * @since Greatnews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function greatnews_pro_is_video_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'greatnews_pro_theme_options[video_content_type]' )->value();
	return greatnews_pro_is_video_section_enable( $control ) && ( 'custom' == $content_type );
}
