<?php
/**
 * Greatnews Pro Customizer.
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function greatnews_pro_customize_register( $wp_customize ) {
	$options = greatnews_pro_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load partial callback functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	// Remove the core header textcolor control, as it shares the main text color.
	$wp_customize->remove_control( 'header_textcolor' );

	// Header title color setting and control.
	$wp_customize->add_setting( 'greatnews_pro_theme_options[header_title_color]', array(
		'default'           => $options['header_title_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'greatnews_pro_theme_options[header_title_color]', array(
		'priority'			=> 5,
		'label'             => esc_html__( 'Header Title Color', 'greatnews-pro' ),
		'section'           => 'colors',
		) ) );

	// Header tagline color setting and control.
	$wp_customize->add_setting( 'greatnews_pro_theme_options[header_tagline_color]', array(
		'default'           => $options['header_tagline_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'greatnews_pro_theme_options[header_tagline_color]', array(
		'priority'			=> 6,
		'label'             => esc_html__( 'Header Tagline Color', 'greatnews-pro' ),
		'section'           => 'colors',
		) ) );

	// Site identity extra options.
	$wp_customize->add_setting( 'greatnews_pro_theme_options[header_txt_logo_extra]', array(
		'default'           => $options['header_txt_logo_extra'],
		'sanitize_callback' => 'greatnews_pro_sanitize_select',
		'transport'			=> 'refresh'
		) );

	$wp_customize->add_control( 'greatnews_pro_theme_options[header_txt_logo_extra]', array(
		'priority'			=> 50,
		'type'				=> 'radio',
		'label'             => esc_html__( 'Site Identity Extra Options', 'greatnews-pro' ),
		'section'           => 'title_tagline',
		'choices'				=> array( 
			'hide-all'     => esc_html__( 'Hide All', 'greatnews-pro' ),
			'show-all'     => esc_html__( 'Show All', 'greatnews-pro' ),
			'title-only'   => esc_html__( 'Title Only', 'greatnews-pro' ),
			'tagline-only' => esc_html__( 'Tagline Only', 'greatnews-pro' ),
			'logo-title'   => esc_html__( 'Logo + Title', 'greatnews-pro' ),
			'logo-tagline' => esc_html__( 'Logo + Tagline', 'greatnews-pro' ),
			)
		) );

	/**
	 * Custom colors.
	 */
	$wp_customize->add_setting( 'greatnews_pro_theme_options[theme_color]', array(
		'default'           => $options['theme_color'],
		'sanitize_callback' => 'greatnews_pro_sanitize_select',
		) );

	$wp_customize->add_control( 'greatnews_pro_theme_options[theme_color]', array(
		'type'    => 'radio',
		'label'    => esc_html__( 'Theme Color', 'greatnews-pro' ),
		'choices'  => array(
			'dark-version'   => esc_html__( 'Dark Version', 'greatnews-pro' ),
			'lite-version'   => esc_html__( 'Lite Version', 'greatnews-pro' ),
			),
		'section'  => 'colors',
		) );

	/**
	 * Custom colors.
	 */
	$wp_customize->add_setting( 'greatnews_pro_theme_options[colorscheme]', array(
		'default'           => $options['colorscheme'],
		'sanitize_callback' => 'greatnews_pro_sanitize_select',
		) );

	$wp_customize->add_control( 'greatnews_pro_theme_options[colorscheme]', array(
		'type'    => 'radio',
		'label'    => esc_html__( 'Color Scheme', 'greatnews-pro' ),
		'choices'  => array(
			'default'   => esc_html__( 'Default', 'greatnews-pro' ),
			'blue'      => esc_html__( 'Blue', 'greatnews-pro' ),
			'green'     => esc_html__( 'Green', 'greatnews-pro' ),
			'red'       => esc_html__( 'Red', 'greatnews-pro' ),
			'yellow'    => esc_html__( 'Yellow', 'greatnews-pro' ),
			'custom'    => esc_html__( 'Custom', 'greatnews-pro' ),
			),
		'section'  => 'colors',
		) );

	$wp_customize->add_setting( 'greatnews_pro_theme_options[colorscheme_hue]', array(
		'default'           => $options['colorscheme_hue'],
		'sanitize_callback' => 'sanitize_hex_color', // The hue is stored as a positive integer.
		) );


	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'greatnews_pro_theme_options[colorscheme_hue]', array(
		'section'  => 'colors',
		) ) );

	// Add panel for common theme options
	$wp_customize->add_panel( 'greatnews_pro_theme_options_panel' , array(
		'title'      => esc_html__( 'Theme Options','greatnews-pro' ),
		'description'=> esc_html__( 'Greatnews Pro Theme Options.', 'greatnews-pro' ),
		'priority'   => 150,
		) );

	// breadcrumb
	require get_template_directory() . '/inc/customizer/theme-options/breadcrumb.php';

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load menu
	require get_template_directory() . '/inc/customizer/theme-options/menu.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/archive.php';
	
	// load single post option
	require get_template_directory() . '/inc/customizer/theme-options/single-posts.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';

	// Add panel for front page theme options.
	$wp_customize->add_panel( 'greatnews_pro_front_page_panel' , array(
		'title'      => esc_html__( 'Front Page','greatnews-pro' ),
		'description'=> esc_html__( 'Front Page Theme Options.', 'greatnews-pro' ),
		'priority'   => 140,
	) );

	require get_template_directory() . '/inc/customizer/sections/home-layout.php';

	// load topbar option
	require get_template_directory() . '/inc/customizer/sections/topbar.php';


	if ( $options['home_layout'] == 'default-design' ) {

		// load breakingnews option
		require get_template_directory() . '/inc/customizer/sections/breakingnews.php';	

		// load hero-section option
		require get_template_directory() . '/inc/customizer/sections/hero-section.php';		

		// load thumbnail-post option
		require get_template_directory() . '/inc/customizer/sections/thumbnail-post.php';	

		// load slider option
		require get_template_directory() . '/inc/customizer/sections/slider.php';

		// load trending option
		require get_template_directory() . '/inc/customizer/sections/trending.php';

		// load most viewed option
		require get_template_directory() . '/inc/customizer/sections/most-viewed-post.php';

		// load media-news option
		require get_template_directory() . '/inc/customizer/sections/media-news.php';

		// load reading option
		require get_template_directory() . '/inc/customizer/sections/reading.php';

		// load single column option
		require get_template_directory() . '/inc/customizer/sections/single-column-news.php';

		// load blog option
		require get_template_directory() . '/inc/customizer/sections/blog.php';

	}

	if ( $options['home_layout'] == 'sixth-design' || $options['home_layout'] == 'twelve-design' ) {

		// load slider option
		require get_template_directory() . '/inc/customizer/sections/slider.php';

		// load service option
		require get_template_directory() . '/inc/customizer/sections/service.php';

		if ( $options['home_layout'] == 'sixth-design' ):

		// load recent-product option
		require get_template_directory() . '/inc/customizer/sections/recent-product.php';

		// load subscription option
		require get_template_directory() . '/inc/customizer/sections/subscription.php';

		// load featured-product option
		require get_template_directory() . '/inc/customizer/sections/featured-product.php';

		endif;

		if ( $options['home_layout'] == 'twelve-design' ):

			// load about option
		require get_template_directory() . '/inc/customizer/sections/about.php';

		// load features option
		require get_template_directory() . '/inc/customizer/sections/features.php';

		// load counter option
		require get_template_directory() . '/inc/customizer/sections/counter.php';

		// load team option
		require get_template_directory() . '/inc/customizer/sections/team.php';

		// load medical-reason option
		require get_template_directory() . '/inc/customizer/sections/medical-reason.php';

		endif;

		// load blog option
		require get_template_directory() . '/inc/customizer/sections/blog.php';

	}

	if ( $options['home_layout'] == 'seventh-design' ) {

		// load slider option
		require get_template_directory() . '/inc/customizer/sections/slider.php';

		// load thumbnail-post option
		require get_template_directory() . '/inc/customizer/sections/thumbnail-post.php';

		// load hero-section option
		require get_template_directory() . '/inc/customizer/sections/hero-section.php';

		// load media-news option
		require get_template_directory() . '/inc/customizer/sections/media-news.php';

		// load most viewed option
		require get_template_directory() . '/inc/customizer/sections/most-viewed-post.php';

		// load subscription option
		require get_template_directory() . '/inc/customizer/sections/subscription.php';

		// load blog option
		require get_template_directory() . '/inc/customizer/sections/blog.php';

	}

		if ( $options['home_layout'] == 'eight-design' ) {

		// load breakingnews option
		require get_template_directory() . '/inc/customizer/sections/breakingnews.php';

		// load slider option
		require get_template_directory() . '/inc/customizer/sections/slider.php';

		// load about option
		require get_template_directory() . '/inc/customizer/sections/about.php';

		// load service option
		require get_template_directory() . '/inc/customizer/sections/service.php';

		// load counter option
		require get_template_directory() . '/inc/customizer/sections/counter.php';

		// load course option
		require get_template_directory() . '/inc/customizer/sections/course.php';

		// load subscription option
		require get_template_directory() . '/inc/customizer/sections/subscription.php';

		// load team option
		require get_template_directory() . '/inc/customizer/sections/team.php';

		// load blog option
		require get_template_directory() . '/inc/customizer/sections/blog.php';

	}

		if ( $options['home_layout'] == 'ninth-design' || $options['home_layout'] == 'ten-design' ) {

		// load breakingnews option
		require get_template_directory() . '/inc/customizer/sections/breakingnews.php';

		// load slider option
		require get_template_directory() . '/inc/customizer/sections/slider.php';

		// load service option
		require get_template_directory() . '/inc/customizer/sections/service.php';

		if( $options['home_layout'] == 'ninth-design' ):

		// load popular-destination option
		require get_template_directory() . '/inc/customizer/sections/popular-destination.php';

		// load subscription option
		require get_template_directory() . '/inc/customizer/sections/subscription.php';

		// load popular-tours option
		require get_template_directory() . '/inc/customizer/sections/popular-tours.php';

		// load counter option
		require get_template_directory() . '/inc/customizer/sections/counter.php';

		endif;

		if( $options['home_layout'] == 'ten-design' ):

		// load cta option
		require get_template_directory() . '/inc/customizer/sections/cta.php';

		// load about option
		require get_template_directory() . '/inc/customizer/sections/about.php';

		// load counter option
		require get_template_directory() . '/inc/customizer/sections/counter.php';

		// load team option
		require get_template_directory() . '/inc/customizer/sections/team.php';

		// load subscription option
		require get_template_directory() . '/inc/customizer/sections/subscription.php';

		endif;

		// load blog option
		require get_template_directory() . '/inc/customizer/sections/blog.php';
		
	}

	if ( $options['home_layout'] == 'eleven-design' ) {

		// load slider option
		require get_template_directory() . '/inc/customizer/sections/slider.php';

		// load about option
		require get_template_directory() . '/inc/customizer/sections/about.php';

		// load cta option
		require get_template_directory() . '/inc/customizer/sections/cta.php';

		// load service option
		require get_template_directory() . '/inc/customizer/sections/service.php';

		// load video option
		require get_template_directory() . '/inc/customizer/sections/video.php';

		// load features option
		require get_template_directory() . '/inc/customizer/sections/features.php';

		// load counter option
		require get_template_directory() . '/inc/customizer/sections/counter.php';

		// load team option
		require get_template_directory() . '/inc/customizer/sections/team.php';

		// load subscription option
		require get_template_directory() . '/inc/customizer/sections/subscription.php';

		// load blog option
		require get_template_directory() . '/inc/customizer/sections/blog.php';



	}


}
add_action( 'customize_register', 'greatnews_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function greatnews_pro_customize_preview_js() {
	wp_enqueue_script( 'greatnews-pro-customizer', get_template_directory_uri() . '/assets/js/customizer' . greatnews_pro_min() . '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'greatnews_pro_customize_preview_js' );

/**
 * Load dynamic logic for the customizer controls area.
 */
function greatnews_pro_customize_control_js() {

	// fontawesome
	wp_enqueue_style( 'font-awesome-css', get_template_directory_uri() . '/assets/css/font-awesome' . greatnews_pro_min() . '.css' );
	
	// Choose from select jquery.
	wp_enqueue_style( 'chosen-css', get_template_directory_uri() . '/assets/css/chosen' . greatnews_pro_min() . '.css' );
	wp_enqueue_script( 'jquery-chosen', get_template_directory_uri() . '/assets/js/chosen.jquery' . greatnews_pro_min() . '.js', array( 'jquery' ), '1.4.2', true );

	// simple icon picker
	wp_enqueue_style( 'simple-iconpicker-css', get_template_directory_uri() . '/assets/css/simple-iconpicker' . greatnews_pro_min() . '.css' );
	wp_enqueue_script( 'jquery-simple-iconpicker', get_template_directory_uri() . '/assets/js/simple-iconpicker' . greatnews_pro_min() . '.js', array( 'jquery' ), '', true );

	wp_enqueue_style( 'greatnews-pro-customize-controls-css', get_template_directory_uri() . '/assets/css/customize-controls' . greatnews_pro_min() . '.css' );
	wp_enqueue_script( 'greatnews-pro-customize-controls', get_template_directory_uri() . '/assets/js/customize-controls' . greatnews_pro_min() . '.js', array(), '1.0', true );
	$greatnews_pro_reset_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'greatnews-pro' )
		);
	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'greatnews-pro-customize-controls', 'greatnews_pro_reset_data', $greatnews_pro_reset_data );
}
add_action( 'customize_controls_enqueue_scripts', 'greatnews_pro_customize_control_js' );

if ( !function_exists( 'greatnews_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Greatnews Pro 1.0.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
function greatnews_pro_reset_options() {
	$options = greatnews_pro_get_theme_options();
	if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
		set_theme_mod( 'greatnews_pro_theme_options', array() );
			// Reset custom header and backgrounds.
		remove_theme_mod( 'header_image' );
		remove_theme_mod( 'header_image_data' );
		remove_theme_mod( 'background_image' );
		remove_theme_mod( 'background_color' );
		remove_theme_mod( 'header_textcolor' );
	}
	else {
		return false;
	}
}
endif;
add_action( 'customize_save_after', 'greatnews_pro_reset_options' );
