<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 * @return array An array of default values
 */

function greatnews_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$greatnews_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#ff4443',
		'colorscheme'					=> 'default',
		'theme_color'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',
		
		// layout 
		'site_layout'         			=> 'default',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'greatnews-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'greatnews-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'greatnews-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'greatnews-pro' ),
		'hide_category'					=> false,
		'hide_date'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Topbar
		'topbar_section_enable'			=> false,
		'secondary_menu_enable'			=> false,
		'social_menu_enable'			=> false,
		'login_text'				=> esc_html__( 'Log In', 'greatnews-pro' ),

		// Breakingnews
		'breakingnews_section_enable'		=> true,
		'breakingnews_slider_auto_play'		=> false,
		'breakingnews_content_type'			=> 'category',
		'breakingnews_count'				=> 3,
		'breakingnews_title'				=> esc_html__( 'Breaking News', 'greatnews-pro' ),

		// hero section
		'hero_title'					=> esc_html__( 'Featured Posts', 'greatnews-pro' ),
		'hero_section_enable'			=> true,
		'hero_content_type'				=> 'category',
		'hero_count'					=> 5,

		// thumbnail section
		'thumbnail_section_enable'			=> true,
		'thumbnail_content_type'			=> 'category',
		'thumbnail_count'					=> 4,

		// Slider
		'slider_title'					=> esc_html__( 'Featured News', 'greatnews-pro' ),
		'slider_section_enable'			=> true,
		'slider_auto_play'				=> false,
		'classic_slider'				=> false,
		'slider_content_type'			=> 'category',
		'slider_count'					=> 4,
		'slider_btn'					=> esc_html__( 'Learn More', 'greatnews-pro' ),

		// media news
		'media_news_section_enable'		=> true,
		'media_news_title'				=> esc_html__( 'Today&#39;s Featured', 'greatnews-pro' ),

		//reading section
		'reading_section_enable'		=> true,
		'reading_title'					=> esc_html__( 'WORTH READING', 'greatnews-pro' ),
		'reading_post_title'			=> esc_html__( 'This is the new team you need to build to make your startup successful', 'greatnews-pro' ),
		'reading_content_type'			=> 'post',
		'reading_post_count'			=> 4,
		'reading_post_content_type'		=> 'category',

			// Single column
		'single_column_section_enable' => true,
		'single_column_title'		=> esc_html__( 'SINGLE COLUMN NEWS', 'greatnews-pro' ),
		'single_column_content_type'	=> 'category',
		'single_column_count'			=> 4,

		// Trending
		'trending_section_enable'		=> true,
		'trending_title'				=> esc_html__( 'Trending News', 'greatnews-pro' ),
		'trending_news_content_type'	=> 'post',
		'trending_news_title'				=> esc_html__( 'This is the new team you need to build', 'greatnews-pro' ),
		'trending_news_description'				=> esc_html__( 'The company has been moving away from Intel’s chipset for years.', 'greatnews-pro' ),
		'trending_post_count'					=> 4,

		// most_viewed
		'most_viewed_section_enable'		=> true,
		'most_viewed_title'					=> esc_html__( '2 COLUMN NEWS', 'greatnews-pro' ),
		'most_viewed_content_type'			=> 'category',
		'most_viewed_count'					=> 4,
		'most_viewed_button'				=> esc_html__( 'Read More', 'greatnews-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_title'					=> esc_html__( 'Related Posts', 'greatnews-pro' ),
		'blog_description'				=> esc_html__( 'E-Commerce theme for WordPress. Visit our shop page to see all main features for Your Store', 'greatnews-pro' ),
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 3,
		'blog_post_column'				=> 'col-4',
		'blog_button'					=> esc_html__( 'Read Full Post', 'greatnews-pro' ),

		//service
		'service_section_enable'		=> true,
		'service_title'					=> esc_html__( 'Our College Services', 'greatnews-pro' ),
		'service_subtitle'				=> esc_html__( 'Join Our College.', 'greatnews-pro' ),
		'service_count'					=> 3,
		'service_posts_column'			=> 3,
		'service_content_type'			=> 'category',

		//Recent Product
		'product_section_enable'		=> false,
		'product_content_type'			=> 'product-category',
		'product_count'					=> 4,
		'product_title'					=> esc_html__( 'Popular Products', 'greatnews-pro' ),
		'product_subtitle'				=> esc_html__( 'Latest spring collection for fashionable person like you.', 'greatnews-pro' ),

		//subscription
		'subscription_section_enable'			=> false,
		'subscription_sub_title'				=> esc_html__( 'Newsletter', 'greatnews-pro' ),
		'subscription_title'					=> esc_html__( 'Get In Touch', 'greatnews-pro' ),
		'subscription_btn_title'				=> esc_html__( 'Subscribe Now', 'greatnews-pro' ),

		
		//featured section
		'featured_section_enable'		=> false,

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'Welcome To Our Campus', 'greatnews-pro' ),
		'about_btn_title'				=> esc_html__( 'Learn More', 'greatnews-pro' ),
		'about_description'				=> esc_html__( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standardLorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit.', 'greatnews-pro' ),

		// counter
		'counter_section_enable'		=> true,
		'counter_count'					=> 4,

		// Course
		'course_title'					=> esc_html__( 'TOP COURSES', 'greatnews-pro' ),
		'course_subtitle'				=> esc_html__( 'Our Featured Course', 'greatnews-pro' ),
		'course_section_enable'			=> true,
		'course_content_type'			=> 'category',
		'course_count'					=> 3,

		// team
		'team_section_enable'		=> true,
		'team_content_type'			=> 'category',
		'team_count'				=> 4,
		'team_title'				=> esc_html__( 'Our Teachers', 'greatnews-pro' ),
		'team_sub_title'			=> esc_html__( 'Our Best Teachers', 'greatnews-pro' ),
		'team_column'				=> 'col-4',

		// popular destination
		'popular_destination_section_enable'	=> true,
		'popular_destination_content_type'		=> 'category',
		'popular_destination_count'				=> 5,
		'popular_destination_title'				=> esc_html__( 'Popular Destinations', 'greatnews-pro' ),
		'popular_destination_description'		=> esc_html__( 'Our Popular Destinations', 'greatnews-pro' ),
		'popular_destination_read_more'			=> esc_html__( 'Read More', 'greatnews-pro' ),

		// popular tours
		'popular_tours_section_enable'	=> true,
		'popular_tours_content_type'		=> 'category',
		'popular_tours_count'				=> 3,
		'popular_tours_title'				=> esc_html__( 'Popular Tours', 'greatnews-pro' ),

		//cta
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'page',
		'cta_title'						=> esc_html__( 'We need Volunteers around the World', 'greatnews-pro' ),
		'cta_button'					=> esc_html__( 'BECOME A VOLUNTEER', 'greatnews-pro' ),

		//features
		'features_section_enable'		=> true,
		'features_title'					=> esc_html__( 'Our Features', 'greatnews-pro' ),
		'features_subtitle'				=> esc_html__( 'Explore Our Completed Projects! Consectetur adipiscing elitt elit tellus, luctus pulvinar dapibus leoconsectetur luctus nec.', 'greatnews-pro' ),
		'features_count'					=> 3,
		'features_posts_column'			=> 3,
		'features_content_type'			=> 'category',

		// Reason
		'reason_section_enable'			=> true,
		'reason_content_type'			=> 'page',
		'reason_title'					=> esc_html__( 'Analysis and Consulting', 'greatnews-pro'),
		'reason_description'			=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit. Fusce sed cursus quam. Nam sit amet sapien eu lorem fringilla ullamcorper. Integer fermentum erat gravida, sagittis quam in, condimentum ligula.', 'greatnews-pro' ),

		//video
		'video_section_enable'			=> true,
		'video_content_type'			=> 'page',
		'video_title'					=> esc_html__( 'Discover the World of Business', 'greatnews-pro' ),
		'video_description'				=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'greatnews-pro' ),

		);

$output = apply_filters( 'greatnews_pro_default_theme_options', $greatnews_pro_default_options );

	// Sort array in ascending order, according to the key:
if ( ! empty( $output ) ) {
	ksort( $output );
}

return $output;
}