<?php
/**
 * Breakingnews Section options
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

// Add Breakingnews section
$wp_customize->add_section( 'greatnews_pro_breakingnews_section', array(
	'title'             => esc_html__( 'Breakingnews','greatnews-pro' ),
	'description'       => esc_html__( 'Breakingnews Section options.', 'greatnews-pro' ),
	'panel'             => 'greatnews_pro_front_page_panel',
	) );

// Breakingnews content enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[breakingnews_section_enable]', array(
	'default'			=> 	$options['breakingnews_section_enable'],
	'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[breakingnews_section_enable]', array(
	'label'             => esc_html__( 'Breakingnews Section Enable', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_breakingnews_section',
	'on_off_label' 		=> greatnews_pro_switch_options(),
	) ) );

// breakingnews title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[breakingnews_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['breakingnews_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[breakingnews_title]', array(
	'label'           	=> esc_html__( 'Readmore Label', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_breakingnews_section',
	'active_callback' 	=> 'greatnews_pro_is_breakingnews_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[breakingnews_title]', array(
		'selector'            => '#breaking-news .breaking-news-wrapper h2.news-title',
		'settings'            => 'greatnews_pro_theme_options[breakingnews_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_breakingnews_title_partial',
		) );
}

// Breaking News Slider auto play enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[breakingnews_slider_auto_play]', array(
	'default'			=> 	$options['breakingnews_slider_auto_play'],
	'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[breakingnews_slider_auto_play]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_breakingnews_section',
	'on_off_label' 		=> greatnews_pro_switch_options(),
	'active_callback'   => 'greatnews_pro_is_breakingnews_section_enable',
	) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[breakingnews_count]', array(
	'default'          	=> $options['breakingnews_count'],
	'sanitize_callback' => 'greatnews_pro_sanitize_number_range',
	'validate_callback' => 'greatnews_pro_validate_breakingnews_count',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[breakingnews_count]', array(
	'label'             => esc_html__( 'Number of Breakingnews', 'greatnews-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_breakingnews_section',
	'active_callback'   => 'greatnews_pro_is_breakingnews_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
	) );

// Breakingnews content type control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[breakingnews_content_type]', array(
	'default'          	=> $options['breakingnews_content_type'],
	'sanitize_callback' => 'greatnews_pro_sanitize_select',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[breakingnews_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_breakingnews_section',
	'type'				=> 'select',
	'active_callback' 	=> 'greatnews_pro_is_breakingnews_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'greatnews-pro' ),
		'post' 		=> esc_html__( 'Post', 'greatnews-pro' ),
		'category' 	=> esc_html__( 'Category', 'greatnews-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['breakingnews_count']; $i++ ) :

	// breakingnews pages drop down chooser control and setting
	$wp_customize->add_setting( 'greatnews_pro_theme_options[breakingnews_content_page_' . $i . ']', array(
		'sanitize_callback' => 'greatnews_pro_sanitize_page',
		) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[breakingnews_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'greatnews-pro' ), $i ),
	'section'           => 'greatnews_pro_breakingnews_section',
	'choices'			=> greatnews_pro_page_choices(),
	'active_callback'	=> 'greatnews_pro_is_breakingnews_section_content_page_enable',
	) ) );

	// breakingnews posts drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[breakingnews_content_post_' . $i . ']', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
	) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[breakingnews_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'greatnews-pro' ), $i ),
	'section'           => 'greatnews_pro_breakingnews_section',
	'choices'			=> greatnews_pro_post_choices(),
	'active_callback'	=> 'greatnews_pro_is_breakingnews_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'greatnews_pro_theme_options[breakingnews_content_category]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Taxonomies_Control( $wp_customize,'greatnews_pro_theme_options[breakingnews_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'greatnews-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_breakingnews_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'greatnews_pro_is_breakingnews_section_content_category_enable'
	) ) );

