<?php
/**
 * CTA Section options
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

// Add CTA section
$wp_customize->add_section( 'greatnews_pro_cta_section', array(
	'title'             => esc_html__( 'CTA','greatnews-pro' ),
	'description'       => esc_html__( 'CTA Section options.', 'greatnews-pro' ),
	'panel'             => 'greatnews_pro_front_page_panel',
) );

// CTA content enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_cta_section',
	'on_off_label' 		=> greatnews_pro_switch_options(),
) ) );

// cta number control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[cta_image]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'greatnews_pro_theme_options[cta_image]', array(
	'label'             => esc_html__( 'Background Image', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_cta_section',
	'active_callback'   => 'greatnews_pro_is_cta_section_enable',
) ) );

// CTA content type control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[cta_content_type]', array(
	'default'          	=> $options['cta_content_type'],
	'sanitize_callback' => 'greatnews_pro_sanitize_select',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[cta_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_cta_section',
	'type'				=> 'select',
	'active_callback' 	=> 'greatnews_pro_is_cta_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'greatnews-pro' ),
		'post' 		=> esc_html__( 'Post', 'greatnews-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'greatnews-pro' ),
	),
) );

// cta pages drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[cta_content_page]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[cta_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_cta_section',
	'choices'			=> greatnews_pro_page_choices(),
	'active_callback'	=> 'greatnews_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[cta_content_post]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[cta_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_cta_section',
	'choices'			=> greatnews_pro_post_choices(),
	'active_callback'	=> 'greatnews_pro_is_cta_section_content_post_enable',
) ) );

// cta title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[cta_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_title'],
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[cta_title]', array(
	'label'           	=> esc_html__( 'Title', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_cta_section',
	'active_callback' 	=> 'greatnews_pro_is_cta_section_content_custom_enable',
	'type'				=> 'text',
) );

// cta title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[cta_button]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_button'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[cta_button]', array(
	'label'           	=> esc_html__( 'Button', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_cta_section',
	'active_callback' 	=> 'greatnews_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[cta_button]', array(
		'selector'            => '#charity-cta div.business-read-more a',
		'settings'            => 'greatnews_pro_theme_options[cta_button]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_cta_button_partial',
    ) );
}

// cta btn link setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[button_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[button_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_cta_section',
	'active_callback' 	=> 'greatnews_pro_is_cta_section_content_custom_enable',
	'type'				=> 'url',
) );