<?php
/**
 * Feature Section options
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

// Add Feature section
$wp_customize->add_section( 'greatnews_pro_features_section', array(
	'title'             => esc_html__( 'Features','greatnews-pro' ),
	'description'       => esc_html__( 'Features Section options.', 'greatnews-pro' ),
	'panel'             => 'greatnews_pro_front_page_panel',
) );

// Feature content enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[features_section_enable]', array(
	'default'			=> 	$options['features_section_enable'],
	'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[features_section_enable]', array(
	'label'             => esc_html__( 'Feature Section Enable', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_features_section',
	'on_off_label' 		=> greatnews_pro_switch_options(),
) ) );

// features title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[features_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['features_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[features_title]', array(
	'label'           	=> esc_html__( 'Title', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_features_section',
	'active_callback' 	=> 'greatnews_pro_is_features_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[features_title]', array(
		'selector'            => '#medical-features h2.business-section-title',
		'settings'            => 'greatnews_pro_theme_options[features_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_features_title_partial',
    ) );
}

// features subtitle setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[features_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['features_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[features_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_features_section',
	'active_callback' 	=> 'greatnews_pro_is_features_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[features_subtitle]', array(
		'selector'            => '#medical-features p.business-section-subtitle',
		'settings'            => 'greatnews_pro_theme_options[features_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_features_subtitle_partial',
    ) );
}

if ( $options['home_layout'] !== 'eleven-design' ):

// Must Read Posts column control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[features_posts_column]', array(
	'default'          	=> $options['features_posts_column'],
	'sanitize_callback' => 'greatnews_pro_sanitize_select',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[features_posts_column]', array(
	'label'             => esc_html__( 'Column Number', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_features_section',
	'type'				=> 'select',
	'active_callback' 	=> 'greatnews_pro_is_features_section_enable',
	'choices'			=> array( 
		3 		=> esc_html__( 'Three Column', 'greatnews-pro' ),
		4 		=> esc_html__( 'Four Column', 'greatnews-pro' ),
	),
) );

endif;

// Event social icons number control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[features_count]', array(
	'default'          	=> $options['features_count'],
	'sanitize_callback' => 'greatnews_pro_sanitize_number_range',
	'validate_callback' => 'greatnews_pro_validate_features_count',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[features_count]', array(
	'label'             => esc_html__( 'Number of Features', 'greatnews-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_features_section',
	'active_callback'   => 'greatnews_pro_is_features_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );


// Feature content type control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[features_content_type]', array(
	'default'          	=> $options['features_content_type'],
	'sanitize_callback' => 'greatnews_pro_sanitize_select',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[features_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_features_section',
	'type'				=> 'select',
	'active_callback' 	=> 'greatnews_pro_is_features_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'greatnews-pro' ),
		'post' 		=> esc_html__( 'Post', 'greatnews-pro' ),
		'category' 	=> esc_html__( 'Category', 'greatnews-pro' ),
	),
) );


for ( $i = 1; $i <= $options['features_count']; $i++ ) :

	if ( $options['home_layout'] !== 'eleven-design' ):

		// features note control and setting
	$wp_customize->add_setting( 'greatnews_pro_theme_options[features_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

	$wp_customize->add_control( new Greatnews_Pro_Icon_Picker( $wp_customize, 'greatnews_pro_theme_options[features_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'greatnews-pro' ), $i ),
		'section'           => 'greatnews_pro_features_section',
		'active_callback'	=> 'greatnews_pro_is_features_section_enable',
		) ) );

	endif;

	// features pages drop down chooser control and setting
	$wp_customize->add_setting( 'greatnews_pro_theme_options[features_content_page_' . $i . ']', array(
		'sanitize_callback' => 'greatnews_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[features_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'greatnews-pro' ), $i ),
		'section'           => 'greatnews_pro_features_section',
		'choices'			=> greatnews_pro_page_choices(),
		'active_callback'	=> 'greatnews_pro_is_features_section_content_page_enable',
	) ) );

	// features posts drop down chooser control and setting
	$wp_customize->add_setting( 'greatnews_pro_theme_options[features_content_post_' . $i . ']', array(
		'sanitize_callback' => 'greatnews_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[features_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'greatnews-pro' ), $i ),
		'section'           => 'greatnews_pro_features_section',
		'choices'			=> greatnews_pro_post_choices(),
		'active_callback'	=> 'greatnews_pro_is_features_section_content_post_enable',
	) ) );
	
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'greatnews_pro_theme_options[features_content_category]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Taxonomies_Control( $wp_customize,'greatnews_pro_theme_options[features_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'greatnews-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_features_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'greatnews_pro_is_features_section_content_category_enable'
) ) );
