<?php
/**
 * Medical Reason Section options
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

// Add Reason section
$wp_customize->add_section( 'greatnews_pro_reason_section', array(
	'title'             => esc_html__( 'Medical Reason','greatnews-pro' ),
	'description'       => esc_html__( 'Medical Reason Section options.', 'greatnews-pro' ),
	'panel'             => 'greatnews_pro_front_page_panel',
) );

// Reason content enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[reason_section_enable]', array(
	'default'			=> 	$options['reason_section_enable'],
	'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[reason_section_enable]', array(
	'label'             => esc_html__( 'Reason Section Enable', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_reason_section',
	'on_off_label' 		=> greatnews_pro_switch_options(),
) ) );

// Reason content type control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[reason_content_type]', array(
	'default'          	=> $options['reason_content_type'],
	'sanitize_callback' => 'greatnews_pro_sanitize_select',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[reason_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_reason_section',
	'type'				=> 'select',
	'active_callback' 	=> 'greatnews_pro_is_reason_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'greatnews-pro' ),
		'post' 		=> esc_html__( 'Post', 'greatnews-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'greatnews-pro' ),
	),
) );

// reason image setting and control.
$wp_customize->add_setting( 'greatnews_pro_theme_options[reason_background_image]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'greatnews_pro_theme_options[reason_background_image]',
		array(
		'label'       		=> esc_html__( 'Content Background Image', 'greatnews-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'greatnews-pro' ), 512, 520 ),
		'section'     		=> 'greatnews_pro_reason_section',
		'active_callback'	=> 'greatnews_pro_is_reason_section_enable',
) ) );

// reason pages drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[reason_content_page]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[reason_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_reason_section',
	'choices'			=> greatnews_pro_page_choices(),
	'active_callback'	=> 'greatnews_pro_is_reason_section_content_page_enable',
) ) );

// reason posts drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[reason_content_post]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[reason_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_reason_section',
	'choices'			=> greatnews_pro_post_choices(),
	'active_callback'	=> 'greatnews_pro_is_reason_section_content_post_enable',
) ) );

// reason title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[reason_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['reason_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[reason_title]', array(
	'label'           	=> esc_html__( 'Title', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_reason_section',
	'active_callback' 	=> 'greatnews_pro_is_reason_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[reason_title]', array(
		'selector'            => '#medical-reasons .entry-container .entry-header h2.entry-title',
		'settings'            => 'greatnews_pro_theme_options[reason_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_reason_title_partial',
    ) );
}

// reason description setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[reason_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['reason_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[reason_description]', array(
	'label'           	=> esc_html__( 'Description', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_reason_section',
	'active_callback' 	=> 'greatnews_pro_is_reason_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[reason_description]', array(
		'selector'            => '#medical-reasons div.entry-container p',
		'settings'            => 'greatnews_pro_theme_options[reason_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_reason_description_partial',
    ) );
}

// reason image setting and control.
$wp_customize->add_setting( 'greatnews_pro_theme_options[reason_image]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'greatnews_pro_theme_options[reason_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'greatnews-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'greatnews-pro' ), 512, 520 ),
		'section'     		=> 'greatnews_pro_reason_section',
		'active_callback'	=> 'greatnews_pro_is_reason_section_content_custom_enable',
) ) );

// reason list
	$wp_customize->add_setting( 'greatnews_pro_theme_options[reason_list]', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Greatnews_Pro_Multi_Input_Custom_Control( $wp_customize, 'greatnews_pro_theme_options[reason_list]', array(
		'label'             => esc_html__( 'Reasin List ', 'greatnews-pro' ),
		'button_text'       => esc_html__( 'Add list.', 'greatnews-pro' ),
		'section'           => 'greatnews_pro_reason_section',
		'active_callback' 	=> 'greatnews_pro_is_reason_section_enable',
		'type'				=> 'text',
	) ) );