<?php
/**
* Reading Post Section options
*
* @package Theme Palace
* @subpackage Magazinew Book Pro
* @since Magazinew Book Pro 1.0.0
*/

// Add Reading Post section
$wp_customize->add_section( 'greatnews_pro_reading_section', array(
	'title'             => esc_html__( 'Reading Post Section','greatnews-pro' ),
	'description'       => esc_html__( 'Reading Post Section options.', 'greatnews-pro' ),
	'panel'             => 'greatnews_pro_front_page_panel',
	) );

// Reading Post content enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[reading_section_enable]', array(
	'default'			=> 	$options['reading_section_enable'],
	'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[reading_section_enable]', array(
	'label'             => esc_html__( 'Reading Post Section Enable', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_reading_section',
	'on_off_label' 		=> greatnews_pro_switch_options(),
	) ) );

// Reading Post btn title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[reading_title]', array(
	'default'			=> 	$options['reading_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[reading_title]', array(
	'label'           	=>  esc_html__( 'Title', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_reading_section',
	'active_callback' 	=> 'greatnews_pro_is_reading_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[reading_title]', array(
		'selector'            => '#reading div.section-header h2.section-title',
		'settings'            => 'greatnews_pro_theme_options[reading_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_reading_title_partial',
		) );
}

// Reading Post content type control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[reading_content_type]', array(
	'default'          	=> $options['reading_content_type'],
	'sanitize_callback' => 'greatnews_pro_sanitize_select',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[reading_content_type]', array(
	'label'             => esc_html__( 'Reading Content Type', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_reading_section',
	'type'				=> 'select',
	'active_callback' 	=> 'greatnews_pro_is_reading_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'greatnews-pro' ),
		'post' 		=> esc_html__( 'Post', 'greatnews-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'greatnews-pro' ),
		),
	) );



// reading_logo pages drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[reading_content_page]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
	) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[reading_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_reading_section',
	'choices'			=> greatnews_pro_page_choices(),
	'active_callback'	=> 'greatnews_pro_is_reading_section_content_page_enable',
	) ) );

// reading_logo posts drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[reading_content_post]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
	) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[reading_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_reading_section',
	'choices'			=> greatnews_pro_post_choices(),
	'active_callback'	=> 'greatnews_pro_is_reading_section_content_post_enable',
	) ) );


// reading news title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[reading_post_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['reading_post_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[reading_post_title]', array(
	'label'           	=> esc_html__( 'Post Title', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_reading_section',
	'active_callback' 	=> 'greatnews_pro_is_reading_section_content_custom_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[reading_post_title]', array(
		'selector'            => '#reading .reading-wrapper  article header h2 a',
		'settings'            => 'greatnews_pro_theme_options[reading_post_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_reading_post_title_partial',
    ) );
}

// reading news image setting and control.
$wp_customize->add_setting( 'greatnews_pro_theme_options[reading_post_image]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_image',
	) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'greatnews_pro_theme_options[reading_post_image]',
	array(
		'label'       		=> esc_html__( 'Background Image', 'greatnews-pro' ),
		'description' 		=> esc_html__( 'Upload background image', 'greatnews-pro' ),
		'section'     		=> 'greatnews_pro_reading_section',
		'active_callback'	=> 'greatnews_pro_is_reading_section_content_custom_enable',
		) ) );

// reading hr setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[reading_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new Greatnews_Pro_Customize_Horizontal_Line( $wp_customize, 'greatnews_pro_theme_options[reading_hr]',
	array(
		'section'         => 'greatnews_pro_reading_section',
		'active_callback' => 'greatnews_pro_is_reading_section_enable',
		'type'			  => 'hr'
		) ) );


// Event social icons number control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[reading_post_count]', array(
	'default'          	=> $options['reading_post_count'],
	'sanitize_callback' => 'greatnews_pro_sanitize_number_range',
	'validate_callback' => 'greatnews_pro_validate_reading_post_count',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[reading_post_count]', array(
	'label'             => esc_html__( 'Number of Related Post', 'greatnews-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_reading_section',
	'active_callback'   => 'greatnews_pro_is_reading_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
	) );

// Reading Post content type control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[reading_post_content_type]', array(
	'default'          	=> $options['reading_post_content_type'],
	'sanitize_callback' => 'greatnews_pro_sanitize_select',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[reading_post_content_type]', array(
	'label'             => esc_html__( 'Reading Post Content Type', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_reading_section',
	'type'				=> 'select',
	'active_callback' 	=> 'greatnews_pro_is_reading_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'greatnews-pro' ),
		'post' 		=> esc_html__( 'Post', 'greatnews-pro' ),
		'category'	=> esc_html__( 'Category', 'greatnews-pro'),
		),
	) );

for ( $i = 1; $i <= $options['reading_post_count']; $i++ ) :

// reading_logo pages drop down chooser control and setting
	$wp_customize->add_setting( 'greatnews_pro_theme_options[reading_post_content_page_' . $i . ']', array(
		'sanitize_callback' => 'greatnews_pro_sanitize_page',
		) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[reading_post_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'greatnews-pro' ), $i ),
	'section'           => 'greatnews_pro_reading_section',
	'choices'			=> greatnews_pro_page_choices(),
	'active_callback'	=> 'greatnews_pro_is_reading_post_section_content_page_enable',
	) ) );

// reading_logo posts drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[reading_post_content_post_' . $i . ']', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
	) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[reading_post_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'greatnews-pro' ), $i ),
	'section'           => 'greatnews_pro_reading_section',
	'choices'			=> greatnews_pro_post_choices(),
	'active_callback'	=> 'greatnews_pro_is_reading_post_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'greatnews_pro_theme_options[reading_post_content_category]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Taxonomies_Control( $wp_customize,'greatnews_pro_theme_options[reading_post_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'greatnews-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_reading_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'greatnews_pro_is_reading_post_section_content_category_enable'
	) ) );




