<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'greatnews_pro_slider_section', array(
	'title'             => esc_html__( 'Post Slider','greatnews-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'greatnews-pro' ),
	'panel'             => 'greatnews_pro_front_page_panel',
	) );

// Slider content enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_slider_section',
	'on_off_label' 		=> greatnews_pro_switch_options(),
	) ) );

if ( $options['home_layout'] == 'default-design' ):

// slider title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[slider_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[slider_title]', array(
	'label'           	=> esc_html__( 'Slider Title', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_slider_section',
	'active_callback' 	=> 'greatnews_pro_is_slider_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[slider_title]', array(
		'selector'            => '#main-post-wrapper #primary #posts-slider h2.section-title',
		'settings'            => 'greatnews_pro_theme_options[slider_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_slider_title_partial',
		) );
}

endif;

// Slider auto play enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[slider_auto_play]', array(
	'default'			=> 	$options['slider_auto_play'],
	'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[slider_auto_play]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_slider_section',
	'on_off_label' 		=> greatnews_pro_switch_options(),
	'active_callback'   => 'greatnews_pro_is_slider_section_enable',
	) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'greatnews_pro_sanitize_number_range',
	'validate_callback' => 'greatnews_pro_validate_slider_count',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'greatnews-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_slider_section',
	'active_callback'   => 'greatnews_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
	) );

// Slider content type control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'greatnews_pro_sanitize_select',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'greatnews_pro_is_slider_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'greatnews-pro' ),
		'post' 		=> esc_html__( 'Post', 'greatnews-pro' ),
		'category' 	=> esc_html__( 'Category', 'greatnews-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'greatnews_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'greatnews_pro_sanitize_page',
		) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[slider_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'greatnews-pro' ), $i ),
	'section'           => 'greatnews_pro_slider_section',
	'choices'			=> greatnews_pro_page_choices(),
	'active_callback'	=> 'greatnews_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[slider_content_post_' . $i . ']', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
	) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[slider_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'greatnews-pro' ), $i ),
	'section'           => 'greatnews_pro_slider_section',
	'choices'			=> greatnews_pro_post_choices(),
	'active_callback'	=> 'greatnews_pro_is_slider_section_content_post_enable',
	) ) );

if ( $options['home_layout'] == 'default-design' ):

	// designation setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[designation_' . $i . ']', array(
	'sanitize_callback' => 'sanitize_text_field',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[designation_' . $i . ']', array(
	'label'           	=> sprintf( esc_html__( 'Designation %d', 'greatnews-pro' ), $i ),
	'section'        	=> 'greatnews_pro_slider_section',
	'active_callback' 	=> 'greatnews_pro_is_slider_section_enable',
	'type'				=> 'text',
	) );

endif;

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'greatnews_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Taxonomies_Control( $wp_customize,'greatnews_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'greatnews-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'greatnews_pro_is_slider_section_content_category_enable'
	) ) );

if ( $options['home_layout'] == 'sixth-design' || $options['home_layout'] == 'seventh-design' || $options['home_layout'] == 'eight-design' || $options['home_layout'] == 'ninth-design' || $options['home_layout'] == 'ten-design' || $options['home_layout'] == 'eleven-design' || $options['home_layout'] == 'twelve-design' ):

// slider button setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[slider_btn]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_btn'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[slider_btn]', array(
	'label'           	=> esc_html__( 'Button', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_slider_section',
	'active_callback' 	=> 'greatnews_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[slider_btn]', array(
		'selector'            => '#business-slider div.business-read-more a',
		'settings'            => 'greatnews_pro_theme_options[slider_btn]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_slider_btn_partial',
    ) );
}

endif;