<?php
/**
 * Topbar Section options
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

// Add Topbar section
$wp_customize->add_section( 'greatnews_pro_topbar_section', array(
	'title'             => esc_html__( 'Topbar','greatnews-pro' ),
	'description'       => esc_html__( 'Topbar Section options.', 'greatnews-pro' ),
	'panel'             => 'greatnews_pro_front_page_panel',
	) );

// Topbar content enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[topbar_section_enable]', array(
	'default'			=> 	$options['topbar_section_enable'],
	'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[topbar_section_enable]', array(
	'label'             => esc_html__( 'Topbar Section Enable', 'greatnews-pro' ),
	'description'       => sprintf( '%1$s <a class="topbar-menu-trigger" href="#"> %2$s </a> %3$s', esc_html__( 'Note: To show secondary and social menu.', 'greatnews-pro' ), esc_html__( 'Click Here', 'greatnews-pro' ), esc_html__( 'to create menu', 'greatnews-pro' ) ),
	'section'           => 'greatnews_pro_topbar_section',
	'on_off_label' 		=> greatnews_pro_switch_options(),
	) ) );

// Login text setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[login_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['login_text'],
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[login_text]', array(
	'label'           	=> esc_html__( 'Top Login text', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_topbar_section',
	'active_callback' 	=> 'greatnews_pro_is_topbar_section_enable',
	'type'				=> 'text',
	) );

// ads link setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[login_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[login_url]', array(
	'label'           	=> esc_html__( 'Login Url', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_topbar_section',
	'type'				=> 'url',
	'active_callback' 	=> 'greatnews_pro_is_topbar_section_enable',
	) );


// mid ads image setting and control.
$wp_customize->add_setting( 'greatnews_pro_theme_options[mid_ads_image]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_image'
	) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'greatnews_pro_theme_options[mid_ads_image]',
	array(
		'label'       		=> esc_html__( 'Mid Ads Image', 'greatnews-pro' ),
		'description' 		=> esc_html__( 'Upload mid Ads Image', 'greatnews-pro' ),
		'section'     		=> 'greatnews_pro_topbar_section',
		) ) );

// mid ads link setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[mid_ads_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[mid_ads_url]', array(
	'label'           	=> esc_html__( 'Mid Ads Url', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_topbar_section',
	'type'				=> 'url',
	) );

// ads image setting and control.
$wp_customize->add_setting( 'greatnews_pro_theme_options[ads_image]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_image'
	) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'greatnews_pro_theme_options[ads_image]',
	array(
		'label'       		=> esc_html__( 'Ads Image', 'greatnews-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'greatnews-pro' ), 900, 100 ),
		'section'     		=> 'greatnews_pro_topbar_section',
		) ) );

// ads link setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[ads_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[ads_url]', array(
	'label'           	=> esc_html__( 'Ads Url', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_topbar_section',
	'type'				=> 'url',
	) );