<?php
/**
 * Trending Section options
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

// Add Trending section
$wp_customize->add_section( 'greatnews_pro_trending_section', array(
	'title'             => esc_html__( 'Trending','greatnews-pro' ),
	'description'       => esc_html__( 'Trending Section options.', 'greatnews-pro' ),
	'panel'             => 'greatnews_pro_front_page_panel',
	) );

// Trending content enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[trending_section_enable]', array(
	'default'			=> 	$options['trending_section_enable'],
	'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[trending_section_enable]', array(
	'label'             => esc_html__( 'Trending Section Enable', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_trending_section',
	'on_off_label' 		=> greatnews_pro_switch_options(),
	) ) );

// trending title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[trending_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['trending_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[trending_title]', array(
	'label'           	=> esc_html__( 'Title', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_trending_section',
	'active_callback' 	=> 'greatnews_pro_is_trending_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[trending_title]', array(
		'selector'            => '#main-post-wrapper #trending-news div.section-header h2.section-title',
		'settings'            => 'greatnews_pro_theme_options[trending_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_trending_title_partial',
		) );
}

// trending news content type control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[trending_news_content_type]', array(
	'default'          	=> $options['trending_news_content_type'],
	'sanitize_callback' => 'greatnews_pro_sanitize_select',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[trending_news_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_trending_section',
	'type'				=> 'select',
	'active_callback' 	=> 'greatnews_pro_is_trending_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'greatnews-pro' ),
		'post' 		=> esc_html__( 'Post', 'greatnews-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'greatnews-pro' ),
		),
	) );

// trending news pages drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[trending_news_content_page]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
	) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[trending_news_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_trending_section',
	'choices'			=> greatnews_pro_page_choices(),
	'active_callback'	=> 'greatnews_pro_is_trending_news_section_content_page_enable',
	) ) );

// trending news posts drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[trending_news_content_post]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
	) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[trending_news_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_trending_section',
	'choices'			=> greatnews_pro_post_choices(),
	'active_callback'	=> 'greatnews_pro_is_trending_news_section_content_post_enable',
	) ) );

// trending news title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[trending_news_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['trending_news_title'],
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[trending_news_title]', array(
	'label'           	=> esc_html__( 'Title', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_trending_section',
	'active_callback' 	=> 'greatnews_pro_is_trending_news_section_content_custom_enable',
	'type'				=> 'text',
	) );

// trending news image setting and control.
$wp_customize->add_setting( 'greatnews_pro_theme_options[trending_news_image]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_image',
	) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'greatnews_pro_theme_options[trending_news_image]',
	array(
		'label'       		=> esc_html__( 'Background Image', 'greatnews-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'greatnews-pro' ), 1280, 854 ),
		'section'     		=> 'greatnews_pro_trending_section',
		'active_callback'	=> 'greatnews_pro_is_trending_news_section_content_custom_enable',
		) ) );

// trending news description setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[trending_news_description]', array(
	'sanitize_callback' => 'sanitize_textarea_field',
	'default'			=> $options['trending_news_description'],
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[trending_news_description]', array(
	'label'           	=> esc_html__( 'Description', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_trending_section',
	'active_callback' 	=> 'greatnews_pro_is_trending_news_section_content_custom_enable',
	'type'				=> 'textarea',
	) );

// trending hr setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[trending_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new Greatnews_Pro_Customize_Horizontal_Line( $wp_customize, 'greatnews_pro_theme_options[trending_hr]',
	array(
		'section'         => 'greatnews_pro_trending_section',
		'active_callback' => 'greatnews_pro_is_trending_section_enable',
		'type'			  => 'hr'
		) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[trending_post_count]', array(
	'default'          	=> $options['trending_post_count'],
	'sanitize_callback' => 'greatnews_pro_sanitize_number_range',
	'validate_callback' => 'greatnews_pro_validate_trending_post_count',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[trending_post_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'greatnews-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_trending_section',
	'active_callback'   => 'greatnews_pro_is_trending_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
	) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'greatnews_pro_theme_options[trending_content_sidebar_category]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_category_list',
	) ) ;

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Category_Control( $wp_customize,'greatnews_pro_theme_options[trending_content_sidebar_category]', array(
	'label'             => esc_html__( 'Select Sidebar Categories', 'greatnews-pro' ),
	'description'      	=> esc_html__( 'Note: Press CTRL and select not more than three categories. Latest five posts will be shown from each selected category', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_trending_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'greatnews_pro_is_trending_section_enable',
	) ) );
