<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function greatnews_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'greatnews-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function greatnews_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'greatnews-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function greatnews_pro_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'greatnews-pro' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function greatnews_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'greatnews-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'greatnews_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function greatnews_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'greatnews-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'greatnews-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'greatnews-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'greatnews-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'greatnews-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'greatnews-pro' ),
        );

        $output = apply_filters( 'greatnews_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function greatnews_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'greatnews-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}


if ( ! function_exists( 'greatnews_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function greatnews_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'greatnews-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'greatnews-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'greatnews-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'greatnews-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'greatnews-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'greatnews-pro' ),
        );

        $output = apply_filters( 'greatnews_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'greatnews_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function greatnews_pro_site_layout() {
        $greatnews_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'greatnews_pro_site_layout', $greatnews_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'greatnews_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function greatnews_pro_selected_sidebar() {
        $greatnews_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'greatnews-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'greatnews-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'greatnews-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'greatnews-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'greatnews-pro' ),
        );

        $output = apply_filters( 'greatnews_pro_selected_sidebar', $greatnews_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'greatnews_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function greatnews_pro_global_sidebar_position() {
        $greatnews_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'greatnews_pro_global_sidebar_position', $greatnews_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'greatnews_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function greatnews_pro_sidebar_position() {
        $greatnews_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'greatnews_pro_sidebar_position', $greatnews_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'greatnews_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function greatnews_pro_pagination_options() {
        $greatnews_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'greatnews-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'greatnews-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'greatnews-pro' ),
        );

        $output = apply_filters( 'greatnews_pro_pagination_options', $greatnews_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'greatnews_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function greatnews_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'greatnews-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'greatnews-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'greatnews-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'greatnews-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'greatnews-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'greatnews-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'greatnews-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'greatnews-pro' ),
        );
        return apply_filters( 'greatnews_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'greatnews_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function greatnews_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'greatnews-pro' ),
            'off'       => esc_html__( 'Disable', 'greatnews-pro' )
        );
        return apply_filters( 'greatnews_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'greatnews_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function greatnews_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'greatnews-pro' ),
            'off'       => esc_html__( 'No', 'greatnews-pro' )
        );
        return apply_filters( 'greatnews_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'greatnews_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function greatnews_pro_sortable_sections() {
        $sections = array(
            'breakingnews'              => esc_html__( 'Breakingnews', 'greatnews-pro' ),
            'hero'                      => esc_html__( 'Hero Section', 'greatnews-pro' ),
            'thumbnail'                 => esc_html__( 'Thumbnail Post', 'greatnews-pro' ),
            'main_post_wrapper'         => esc_html__( 'Main Post', 'greatnews-pro' ),
            'media_news'                => esc_html__( 'Media News', 'greatnews-pro' ),
            'secondary_post_wrapper'    => esc_html__( 'Secondary Post', 'greatnews-pro' ),
            'blog'                      => esc_html__( 'Blog', 'greatnews-pro' ),
        );
        return apply_filters( 'greatnews_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'greatnews_pro_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function greatnews_pro_product_content_type() {
        $greatnews_pro_product_content_type = array(
            'product'   => esc_html__( 'Product', 'greatnews-pro' ),
            'product-category'   => esc_html__( 'Product Category', 'greatnews-pro' ),
        );

        $output = apply_filters( 'greatnews_pro_product_content_type', $greatnews_pro_product_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'greatnews_pro_popular_destination_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function greatnews_pro_popular_destination_content_type() {
        $greatnews_pro_popular_destination_content_type = array(
            'page'      => esc_html__( 'Page', 'greatnews-pro' ),
            'post'      => esc_html__( 'Post', 'greatnews-pro' ),
            'category'  => esc_html__( 'Category', 'greatnews-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $greatnews_pro_popular_destination_content_type = array_merge( $greatnews_pro_popular_destination_content_type, array(
                'trip'          => esc_html__( 'Trip', 'greatnews-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'greatnews-pro' ),
                'destination'   => esc_html__( 'Destination', 'greatnews-pro' ),
                'activity'      => esc_html__( 'Activity', 'greatnews-pro' ),
                ) );
        }

        $output = apply_filters( 'greatnews_pro_popular_destination_content_type', $greatnews_pro_popular_destination_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'greatnews_pro_popular_tours_content_type' ) ) :
    /**
     * Tours Options
     * @return array site gallery options
     */
    function greatnews_pro_popular_tours_content_type() {
        $greatnews_pro_popular_tours_content_type = array(
            'page'      => esc_html__( 'Page', 'greatnews-pro' ),
            'post'      => esc_html__( 'Post', 'greatnews-pro' ),
            'category'  => esc_html__( 'Category', 'greatnews-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $greatnews_pro_popular_tours_content_type = array_merge( $greatnews_pro_popular_tours_content_type, array(
                'trip'          => esc_html__( 'Trip', 'greatnews-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'greatnews-pro' ),
                'tours'         => esc_html__( 'Tours', 'greatnews-pro' ),
                'activity'      => esc_html__( 'Activity', 'greatnews-pro' ),
                ) );
        }

        $output = apply_filters( 'greatnews_pro_popular_tours_content_type', $greatnews_pro_popular_tours_content_type );


        return $output;
    }
endif;