<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */
if ( ! function_exists( 'greatnews_pro_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Greatnews Pro 1.0.0
    */
    function greatnews_pro_add_blog_section() {
    	$options = greatnews_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'greatnews_pro_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'greatnews_pro_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        greatnews_pro_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'greatnews_pro_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Greatnews Pro 1.0.0
    * @param array $input blog section details.
    */
    function greatnews_pro_get_blog_section_details( $input ) {
        $options = greatnews_pro_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        $blog_count = ! empty( $options['blog_count'] ) ? $options['blog_count'] : 4;
        
        $content = array();
        switch ( $blog_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['auth_id']   = get_the_author_meta('ID');
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = greatnews_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'greatnews_pro_filter_blog_section_details', 'greatnews_pro_get_blog_section_details' );


if ( ! function_exists( 'greatnews_pro_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Greatnews Pro 1.0.0
   *
   */
   function greatnews_pro_render_blog_section( $content_details = array() ) {
        $options = greatnews_pro_get_theme_options();
        $blog_content_type  = $options['blog_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php if ( $options['home_layout'] == 'default-design' ) { ?>

        <div id="related-posts" class="grid-layout">
            <div class="wrapper">
                <?php if ( ! empty( $options['blog_title'] ) ) : ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <div class="section-content <?php echo esc_attr( $options['blog_post_column'] ); ?> clear">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article class="has-post-thumbnail">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <?php if($options['home_layout'] == 'default-design'){ ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                </div>

                                <div class="entry-meta">
                                    <?php greatnews_pro_posted_on( $content['id'] );

                                    if ( 'page' !== $blog_content_type ) : ?>
                                    <span class="cat-links">
                                        <?php the_category( '', '', $content['id'] ); ?>
                                    </span><!-- .cat-links -->
                                <?php endif; ?>
                            </div><!-- .entry-meta -->

                            <?php }else{

                                if ( 'page' !== $blog_content_type ) : ?>
                                <span class="cat-links">
                                    <?php the_category( '', '', $content['id'] ); ?>
                                </span><!-- .cat-links -->
                            <?php endif; ?>

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                            </div>

                            <div class="entry-meta">
                                <?php greatnews_pro_posted_on( $content['id'] );
                            } ?>
                        </div><!-- .entry-container -->
                    </article>
                <?php endforeach; ?>
            </div><!-- .section-content -->
        </div><!-- .wrapper -->
    </div><!-- #most-viewed-posts -->
    <?php }

     if ( $options['home_layout'] == 'sixth-design' || $options['home_layout'] == 'eight-design' || $options['home_layout'] == 'ninth-design' || $options['home_layout'] == 'ten-design' || $options['home_layout'] == 'eleven-design' ){ ?>

    <div id="business-latest-posts" class="relative page-section no-padding-top">
        <div class="wrapper">
            <div class="business-section-header">

            <?php if ( ! empty( $options['blog_title'] ) ) : ?>
                <h2 class="business-section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
            <?php endif;

            if ( ! empty( $options['blog_description'] ) ) : ?>
                <p class="business-section-subtitle"><?php echo esc_html( $options['blog_description'] ); ?></p>
            <?php endif; ?>
            </div><!-- .business-section-header -->

            <div class="business-section-content clear <?php echo esc_attr( $options['blog_post_column'] ); ?>">

            <?php foreach ( $content_details as $content ) : ?>

                <article class="has-post-thumbnail">
                    <div class="business-post-item">
                        <div class="featured-image">
                            <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_html( $content['title'] ); ?>"></a>
                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <div class="entry-meta clear">
                                <span class="posted-on">
                                    <?php greatnews_pro_posted_on( $content['id'] ); ?>
                                </span><!-- .posted-on -->

                                <?php if( !empty( $options['blog_button'] ) ): ?>
                                <span class="more-link"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $options['blog_button'] ); ?></a></span>
                            <?php endif; ?>
                            </div><!-- .entry-meta -->
                        </div><!-- .entry-container -->
                    </div><!-- .business-post-item -->
                </article>

            <?php endforeach; ?>
            </div><!-- .business-section-content -->
        </div><!-- .wrapper -->
    </div>

    <?php }

    if ( $options['home_layout'] == 'seventh-design' ){ ?>

    <div id="blog-latest-posts" class="relative page-section">
        <div class="wrapper">

        <?php if ( ! empty( $options['blog_title'] ) ) : ?>
            <div class="section-header">
                <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
            </div><!-- .section-header -->
        <?php endif; ?>

            <div class="section-content clear">

            <?php foreach ( $content_details as $content ) : ?>

                <article>
                    <div class="blog-post-wrapper">
                    <?php if ( 'page' !== $blog_content_type ) : ?>
                        <span class="cat-links">
                            <?php the_category( '', '', $content['id'] ); ?>                          
                        </span><!-- .cat-links -->
                    <?php endif; ?>

                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                        </header>

                        <span class="posted-on">
                            <?php greatnews_pro_posted_on( $content['id'] ); ?>
                        </span>

                        <div class="featured-image">
                            <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>"></a>
                        </div><!-- .featured-image -->

                        <div class="entry-content">
                            <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                        </div><!-- .entry-content -->

                        <?php if( !empty( $options['blog_button'] ) ): ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $options['blog_button'] ); ?></a>
                        </div><!-- .read-more  -->
                    <?php endif; ?>
                    </div><!-- .blog-post-wrapper -->
                </article>

            <?php endforeach; ?>

            </div><!-- .section-content -->
        </div><!-- .wrapper -->
    </div>

    <?php 
    }

    if ( $options['home_layout'] == 'twelve-design' ){ ?>

    <div id="medical-news" class="relative page-section">
        <div class="wrapper">
            <div class="business-section-header">
                <?php if( !empty( $options['blog_title'] ) ): ?>
                    <h2 class="business-section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
                <?php endif;
                if( !empty( $options['blog_description'] ) ):
                 ?>
             <p class="business-section-subtitle"><?php echo esc_html( $options['blog_description'] ); ?></p>
         <?php endif; ?>
     </div><!-- .business-section-header -->


     <div class="business-section-content <?php echo esc_attr( $options['blog_post_column'] ); ?> clear">

       <?php foreach ( $content_details as $content ) : ?>

        <article>
            <div class="medical-news-item">
                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                    <div class="date"><?php greatnews_pro_posted_on( $content['id'] ); ?></div>
                </div><!-- .featured-image -->

                <div class="entry-container">
                    <header class="entry-header">
                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                    </header>

                    <div class="entry-content">
                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                    </div><!-- .entry-content -->

                    <?php if( !empty( $options['blog_button'] ) ): ?>
                        <div class="post-read-more">
                            <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $options['blog_button'] ); ?></a>
                        </div><!-- .post-read-more -->
                    <?php endif; ?>
                </div><!-- .entry-container -->
            </div><!-- .medical-news-item -->
        </article>

    <?php endforeach; ?>


</div><!-- .section-content -->
</div><!-- .wrapper -->
</div><!-- #medical-news -->

  <?php  }

    }  
endif;