<?php
/**
 * Breakingnews section
 *
 * This is the template for the content of breakingnews section
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */
if ( ! function_exists( 'greatnews_pro_add_breakingnews_section' ) ) :
    /**
    * Add breakingnews section
    *
    *@since Greatnews Pro 1.0.0
    */
    function greatnews_pro_add_breakingnews_section() {
    	$options = greatnews_pro_get_theme_options();
        // Check if breakingnews is enabled on frontpage
        $breakingnews_enable = apply_filters( 'greatnews_pro_section_status', true, 'breakingnews_section_enable' );

        if ( true !== $breakingnews_enable ) {
            return false;
        }
        // Get breakingnews section details
        $section_details = array();
        $section_details = apply_filters( 'greatnews_pro_filter_breakingnews_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render breakingnews section now.
        greatnews_pro_render_breakingnews_section( $section_details );
    }
endif;

if ( ! function_exists( 'greatnews_pro_get_breakingnews_section_details' ) ) :
    /**
    * breakingnews section details.
    *
    * @since Greatnews Pro 1.0.0
    * @param array $input breakingnews section details.
    */
    function greatnews_pro_get_breakingnews_section_details( $input ) {
        $options = greatnews_pro_get_theme_options();

        // Content type.
        $breakingnews_content_type  = $options['breakingnews_content_type'];
        $breakingnews_count = ! empty( $options['breakingnews_count'] ) ? $options['breakingnews_count'] : 3;
        
        $content = array();
        switch ( $breakingnews_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $breakingnews_count; $i++ ) {
                    if ( ! empty( $options['breakingnews_content_page_' . $i] ) )
                        $page_ids[] = $options['breakingnews_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $breakingnews_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $breakingnews_count; $i++ ) {
                    if ( ! empty( $options['breakingnews_content_post_' . $i] ) )
                        $post_ids[] = $options['breakingnews_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $breakingnews_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['breakingnews_content_category'] ) ? $options['breakingnews_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $breakingnews_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// breakingnews section content details.
add_filter( 'greatnews_pro_filter_breakingnews_section_details', 'greatnews_pro_get_breakingnews_section_details' );


if ( ! function_exists( 'greatnews_pro_render_breakingnews_section' ) ) :
  /**
   * Start breakingnews section
   *
   * @return string breakingnews content
   * @since Greatnews Pro 1.0.0
   *
   */
   function greatnews_pro_render_breakingnews_section( $content_details = array() ) {
        $options = greatnews_pro_get_theme_options();
        $title = ! empty( $options['breakingnews_title'] ) ? $options['breakingnews_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="breaking-news" class="relative wrapper">
            <div class="breaking-news-wrapper">
            <?php if( !empty( $title ) ): ?>
                <h2 class="news-title"><?php echo esc_html( $title ); ?></h2>
            <?php endif; ?>
                <div class="breaking-news-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": <?php echo $options['breakingnews_slider_auto_play'] ? 'true' : 'false'; ?>, "draggable": true, "fade": true }'>
                    <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="breaking-news-item-wrapper">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>
                            </div><!-- .breaking-news-item-wrapper -->
                        </article>
                    <?php endforeach; ?>

                </div><!-- .breaking-news-slider -->
            </div><!-- .breaking-news-wrapper -->
        </div><!-- #breaking-news -->
        
    <?php }
endif;