<?php
/**
 * features section
 *
 * This is the template for the content of features section
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */
if ( ! function_exists( 'greatnews_pro_add_features_section' ) ) :
    /**
    * Add features section
    *
    *@since Greatnews Pro 1.0.0
    */
    function greatnews_pro_add_features_section() {
    	$options = greatnews_pro_get_theme_options();
        // Check if features is enabled on frontpage
        $features_enable = apply_filters( 'greatnews_pro_section_status', true, 'features_section_enable' );

        if ( true !== $features_enable ) {
            return false;
        }
        // Get features section details
        $section_details = array();
        $section_details = apply_filters( 'greatnews_pro_filter_features_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render features section now.
        greatnews_pro_render_features_section( $section_details );
    }
endif;

if ( ! function_exists( 'greatnews_pro_get_features_section_details' ) ) :
    /**
    * features section details.
    *
    * @since Greatnews Pro 1.0.0
    * @param array $input features section details.
    */
    function greatnews_pro_get_features_section_details( $input ) {
        $options = greatnews_pro_get_theme_options();

        // Content type.
        $features_content_type  = $options['features_content_type'];
        $features_count = ! empty( $options['features_count'] ) ? $options['features_count'] : 3;
        
        $content = array();
        switch ( $features_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $features_count; $i++ ) {
                    if ( ! empty( $options['features_content_page_' . $i] ) )
                        $page_ids[] = $options['features_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $features_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $features_count; $i++ ) {
                    if ( ! empty( $options['features_content_post_' . $i] ) )
                        $post_ids[] = $options['features_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $features_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['features_content_category'] ) ? $options['features_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $features_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = greatnews_pro_trim_content( 25 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// features section content details.
add_filter( 'greatnews_pro_filter_features_section_details', 'greatnews_pro_get_features_section_details' );


if ( ! function_exists( 'greatnews_pro_render_features_section' ) ) :
  /**
   * Start features section
   *
   * @return string features content
   * @since Greatnews Pro 1.0.0
   *
   */
   function greatnews_pro_render_features_section( $content_details = array() ) {
        $options = greatnews_pro_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <?php if ( $options['home_layout'] == 'twelve-design' ){ ?>
        <div id="medical-features" class="relative page-section">
                <div class="wrapper">
                    <div class="business-section-header">
                    <?php if( !empty( $options['features_title'] ) ): ?>
                        <h2 class="business-section-title"><?php echo esc_html( $options['features_title'] ); ?></h2>
                    <?php endif;
                    if( !empty( $options['features_subtitle'] ) ):
                    ?>
                        <p class="business-section-subtitle"><?php echo esc_html( $options['features_subtitle'] ); ?></p>
                    <?php endif; ?>
                    </div><!-- .business-section-header -->

                    <div class="business-section-content col-<?php echo esc_attr( $options['features_posts_column'] ); ?> clear">
                        
                        <?php foreach ($content_details as $i=>$content) : ?>

                        <article>
                            <div class="medical-feature-item">
                                <div class="feature-icon">
                                    <a href="<?php echo esc_url($content['url']); ?>"><i class="fa <?php echo ! empty( $options['features_content_icon_' . ($i+1) . ''] ) ? esc_attr( $options['features_content_icon_' . ($i+1) . ''] ) : 'fa-cogs' ; ?>"></i></a>
                                </div><!-- .feature-icon -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->
                            </div><!-- .medical-feature-item -->
                        </article>

                        <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>

            <?php } 

            if ( $options['home_layout'] == 'eleven-design' ) { ?>

            <div id="media-news" class="relative tabs">
                <div class="wrapper">
                    <div class="business-section-header">
                    <?php if( !empty( $options['features_title'] ) ): ?>
                        <h2 class="business-section-title"><?php echo esc_html( $options['features_title'] ); ?></h2>
                    <?php endif;

                    if( !empty( $options['features_subtitle'] ) ):
                     ?>
                        <p class="business-section-subtitle"><?php echo esc_html( $options['features_subtitle'] ); ?></p>
                    <?php endif; ?>
                    </div><!-- .business-section-header -->

                    <div id="all" class="tab-content active">
                        <div class="grid">

                        <?php $count = 1; foreach ( $content_details as $content ) : ?>

                            <article class="grid-item <?php echo ( $count == 2 ) ? 'large-width' : ''; ?>">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                </div>
                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <?php if( $count == 2 ): ?>
                                        <div class="entry-content">
                                            <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                        </div>
                                    <?php endif; ?>

                                    <div class="entry-meta">
                                        <span class="posted-on">
                                            <?php greatnews_pro_posted_on( $content['id'] ); ?>
                                        </span><!-- .posted-on -->

                                        <span class="cat-links">
                                            <ul class="post-categories">
                                                <?php the_category( '', '', $content['id'] ); ?>
                                            </ul>
                                        </span><!-- .cat-links -->
                                    </div><!-- .entry-meta -->
                                </div><!-- .entry-container -->
                            </article>

                            <?php $count++; endforeach; ?>

                        </div><!-- .grid-item -->
                    </div><!-- .tab-content -->
                </div><!-- .wrapper -->
            </div>

            <?php } ?>

    <?php }
endif;