<?php
/**
 * Hero section
 *
 * This is the template for the content of hero section
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */
if ( ! function_exists( 'greatnews_pro_add_hero_section' ) ) :
    /**
    * Add hero section
    *
    *@since Greatnews Pro 1.0.0
    */
    function greatnews_pro_add_hero_section() {
    	$options = greatnews_pro_get_theme_options();
        // Check if hero is enabled on frontpage
        $hero_enable = apply_filters( 'greatnews_pro_section_status', true, 'hero_section_enable' );

        if ( true !== $hero_enable ) {
            return false;
        }
        // Get hero section details
        $section_details = array();
        $section_details = apply_filters( 'greatnews_pro_filter_hero_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render hero section now.
        greatnews_pro_render_hero_section( $section_details );
    }
endif;

if ( ! function_exists( 'greatnews_pro_get_hero_section_details' ) ) :
    /**
    * hero section details.
    *
    * @since Greatnews Pro 1.0.0
    * @param array $input hero section details.
    */
    function greatnews_pro_get_hero_section_details( $input ) {
        $options = greatnews_pro_get_theme_options();

        // Content type.
        $hero_content_type  = $options['hero_content_type'];
        $hero_count = ! empty( $options['hero_count'] ) ? $options['hero_count'] : 4;
        
        $content = array();
        switch ( $hero_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $hero_count; $i++ ) {
                    if ( ! empty( $options['hero_content_page_' . $i] ) )
                        $page_ids[] = $options['hero_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $hero_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $hero_count; $i++ ) {
                    if ( ! empty( $options['hero_content_post_' . $i] ) )
                        $post_ids[] = $options['hero_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $hero_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['hero_content_category'] ) ? $options['hero_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $hero_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['auth_id']   = get_the_author_meta('ID');
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = greatnews_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// hero section content details.
add_filter( 'greatnews_pro_filter_hero_section_details', 'greatnews_pro_get_hero_section_details' );


if ( ! function_exists( 'greatnews_pro_render_hero_section' ) ) :
  /**
   * Start hero section
   *
   * @return string hero content
   * @since Greatnews Pro 1.0.0
   *
   */
   function greatnews_pro_render_hero_section( $content_details = array() ) {
        $options = greatnews_pro_get_theme_options();
        $hero_content_type  = $options['hero_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php if ( $options['home_layout'] == 'default-design' ){ ?>

        <div id="hero-section" class="relative">
            <div class="wrapper">
                <div class="grid">
                    <?php foreach ( $content_details as $content ) : ?>

                        <article class="grid-item">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');"></div>
                            <?php 
                                if($options['home_layout'] == 'default-design'){ ?>

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-meta">
                                        <?php if ( 'page' !== $hero_content_type ) : ?>

                                            <span class="cat-links">
                                                <?php the_category( '', '', $content['id'] ); ?>
                                            </span><!-- .cat-links -->

                                        <?php endif; ?>
                                        <?php  greatnews_pro_posted_on( $content['id'] ); ?>
                                    </div><!-- .entry-meta -->
                                </div><!-- .entry-container -->

                            <?php

                                }else{ ?>
                                <div class="entry-container">
                                
                                    <?php if ( 'page' !== $hero_content_type ) : ?>

                                        <span class="cat-links">
                                            <?php the_category( '', '', $content['id'] ); ?>
                                        </span><!-- .cat-links -->

                                    <?php endif; ?>

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-meta">
                                        <?php  greatnews_pro_posted_on( $content['id'] ); ?>
                                    </div><!-- .entry-meta -->
                                </div><!-- .entry-container -->
                            <?php } ?>

                        </article>

                    <?php endforeach; ?>
                </div><!-- .grid-item -->
            </div><!-- .wrapper -->
        </div><!-- #hero-section -->
        <?php } 

        if ( $options['home_layout'] == 'seventh-design' ) { ?>

        <div id="blog-featured-posts" class="relative page-section">
            <div class="wrapper">
            <?php if( !empty( $options['hero_title'] ) ): ?>
                <div class="section-header">
                <h2 class="section-title"><?php echo esc_html( $options['hero_title'] ); ?></h2>
                </div><!-- .section-header -->
            <?php endif; ?>

                <div class="blog-section-content clear">

                <?php foreach ( $content_details as $content ) : ?>

                    <article>
                        <div class="blog-featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">

                        </div><!-- .blog-featured-image -->
                        <div class="entry-container">

                        <?php if ( 'page' !== $hero_content_type ) : ?>

                            <span class="cat-links">
                                <?php the_category( '', '', $content['id'] ); ?>                       
                            </span><!-- .cat-links -->

                        <?php endif; ?>

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <span class="posted-on">
                                <?php  greatnews_pro_posted_on( $content['id'] ); ?>
                            </span><!-- .posted-on -->
                        </div><!-- .entry-container -->
                    </article>

                <?php endforeach; ?>

                </div><!-- .blog-section-content -->
            </div><!-- .wrapper -->
        </div>

      <?php }  ?>



    <?php }
endif;