<?php
/**
 * Featured section
 *
 * This is the template for the content of media-news section
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */
if ( ! function_exists( 'greatnews_pro_add_media_news_section' ) ) :
    /**
    * Add media-news section
    *
    *@since Greatnews Pro 1.0.0
    */
    function greatnews_pro_add_media_news_section() {
        $options = greatnews_pro_get_theme_options();
        // Check if media-news is enabled on frontpage
        $media_news_enable = apply_filters( 'greatnews_pro_section_status', true, 'media_news_section_enable' );

        if ( true !== $media_news_enable ) {
            return false;
        }
        // Get media-news section details
        $section_details = array();
        $section_details = apply_filters( 'greatnews_pro_filter_media_news_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render media-news section now.
        greatnews_pro_render_media_news_section( $section_details );
    }
endif;

if ( ! function_exists( 'greatnews_pro_get_media_news_section_details' ) ) :
    /**
    * media-news section details.
    *
    * @since Greatnews Pro 1.0.0
    * @param array $input media-news section details.
    */
    function greatnews_pro_get_media_news_section_details( $input ) {
        $options = greatnews_pro_get_theme_options();

            $cats = ! empty( $options['media_news_content_category'] ) ? $options['media_news_content_category'] : array();
            $content = array();
            $i = 0;
            foreach ( $cats as $cat_id ) :
                $content[$i] = array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => 5,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    


                // Run The Loop.
                $query = new WP_Query( $args );
                if ( $query->have_posts() ) : 
                    while ( $query->have_posts() ) : $query->the_post();
                        $page_post[$i]['id']        = get_the_id();
                        $page_post['auth_id']       = get_the_author_meta('ID');
                        $page_post[$i]['title']     = get_the_title();
                        $page_post[$i]['excerpt']   = greatnews_pro_trim_content( 25 );
                        $page_post[$i]['url']       = get_the_permalink();
                        $page_post[$i]['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                        // Push to the main array.
                        array_push( $content[$i], $page_post[$i] );
                    endwhile;
                endif;
                wp_reset_postdata();
                $i++;
            endforeach;

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// media-news section content details.
add_filter( 'greatnews_pro_filter_media_news_section_details', 'greatnews_pro_get_media_news_section_details' );


if ( ! function_exists( 'greatnews_pro_render_media_news_section' ) ) :
  /**
   * Start media-news section
   *
   * @return string media-news content
   * @since Greatnews Pro 1.0.0
   *
   */
   function greatnews_pro_render_media_news_section( $content_details = array() ) {
        $options = greatnews_pro_get_theme_options();
        $cats = ! empty( $options['media_news_content_category'] ) ? $options['media_news_content_category'] : array();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="media-news" class="relative tabs">
            <div class="wrapper">
                <div class="section-header-wrapper">

                    <?php if ( ! empty( $options['media_news_title'] ) ) : ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['media_news_title'] ); ?></h2>
                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <ul id="ajax-filter" class="tabs">

                        <?php
                        $i = 1;
                        foreach ( $cats as $cat ) :
                           ?>
                       <li data-tab="<?php echo absint( $cat ); ?>" class="<?php echo ( $i == 1 ) ? 'active' : ''; ?>"><a href="#"><?php echo esc_html( get_cat_name( $cat ) ); ?></a></li>
                       <?php $i++; endforeach; ?>

                </ul><!-- #ajax-filter -->
            </div><!-- .section-header-wrapper -->

            <?php $i = 0; foreach ( $content_details as $content_detail ) : ?>

            <div id="<?php echo absint( $cats[$i] ); ?>" class="tab-content <?php echo ( $i == 0 ) ? 'active' : ''; ?>">
                <div class="grid">
                    <?php $count = 1; foreach ( $content_detail as $content ) : ?>
                    <article class="grid-item <?php echo ( $count == 2 ) ? 'large-width' : ''; ?>">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                        </div>
                        <div class="entry-container">
                            <?php if($options['home_layout'] == 'default-design' || $options['home_layout'] == 'seventh-design' ){ ?>

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <?php if( $count == 2 ): ?>
                                <div class="entry-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                </div>
                            <?php endif; ?>

                            <div class="entry-meta">
                                <?php greatnews_pro_posted_on( $content['id'] ); ?>

                                <span class="cat-links">
                                    <?php the_category( '', '', $content['id'] ); ?>
                                </span><!-- .cat-links -->
                            </div><!-- .entry-meta -->

                            <?php }else{ ?>

                            <span class="cat-links">
                                <?php the_category( '', '', $content['id'] ); ?>
                            </span><!-- .cat-links -->
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <?php if( $count == 2 ): ?>
                                <div class="entry-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                </div>
                            <?php endif; ?>

                            <div class="entry-meta">
                                <?php greatnews_pro_posted_on( $content['id'] ); ?>
                            </div><!-- .entry-meta -->
                            <?php } ?>
                        </div><!-- .entry-container -->
                    </article>

                    <?php $count++; endforeach; ?>

                </div><!-- .grid-item -->
            </div><!-- .tab-content -->

            <?php $i++; endforeach; ?>


        </div><!-- .wrapper -->
    </div><!-- #media-news -->

    <?php }
endif;