<?php
/**
* Thumbnail section
*
* This is the template for the content of thumbnail section
*
* @package Theme Palace
* @subpackage Greatnews Pro
* @since Greatnews Pro 1.0.0
*/
if ( ! function_exists( 'greatnews_pro_add_thumbnail_section' ) ) :
/**
* Add thumbnail section
*
*@since Greatnews Pro 1.0.0
*/
function greatnews_pro_add_thumbnail_section() {
    $options = greatnews_pro_get_theme_options();
// Check if thumbnail is enabled on frontpage
    $thumbnail_enable = apply_filters( 'greatnews_pro_section_status', true, 'thumbnail_section_enable' );

    if ( true !== $thumbnail_enable ) {
        return false;
    }
// Get thumbnail section details
    $section_details = array();
    $section_details = apply_filters( 'greatnews_pro_filter_thumbnail_section_details', $section_details );

    if ( empty( $section_details ) ) {
        return;
    }

// Render thumbnail section now.
    greatnews_pro_render_thumbnail_section( $section_details );
}
endif;

if ( ! function_exists( 'greatnews_pro_get_thumbnail_section_details' ) ) :
/**
* thumbnail section details.
*
* @since Greatnews Pro 1.0.0
* @param array $input thumbnail section details.
*/
function greatnews_pro_get_thumbnail_section_details( $input ) {
    $options = greatnews_pro_get_theme_options();

// Content type.
    $thumbnail_content_type  = $options['thumbnail_content_type'];
    $thumbnail_count = ! empty( $options['thumbnail_count'] ) ? $options['thumbnail_count'] : 4;

    $content = array();
    switch ( $thumbnail_content_type ) {

        case 'page':
        $page_ids = array();

        for ( $i = 1; $i <= $thumbnail_count; $i++ ) {
            if ( ! empty( $options['thumbnail_content_page_' . $i] ) )
                $page_ids[] = $options['thumbnail_content_page_' . $i];
        }

        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( $thumbnail_count ),
            'orderby'           => 'post__in',
            );                    
        break;

        case 'post':
        $post_ids = array();

        for ( $i = 1; $i <= $thumbnail_count; $i++ ) {
            if ( ! empty( $options['thumbnail_content_post_' . $i] ) )
                $post_ids[] = $options['thumbnail_content_post_' . $i];
        }

        $args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => absint( $thumbnail_count ),
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
            );                    
        break;

        case 'category':
        $cat_id = ! empty( $options['thumbnail_content_category'] ) ? $options['thumbnail_content_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => absint( $thumbnail_count ),
            'cat'               => absint( $cat_id ),
            'ignore_sticky_posts'   => true,
            );                    
        break;

        default:
        break;
    }


// Run The Loop.
    $query = new WP_Query( $args );
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
    $page_post['id']        = get_the_id();
    $page_post['title']     = get_the_title();
    $page_post['auth_id']   = get_the_author_meta('ID');
    $page_post['url']       = get_the_permalink();
    $page_post['excerpt']   = greatnews_pro_trim_content( 20 );
    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

// Push to the main array.
    array_push( $content, $page_post );
    endwhile;
    endif;
    wp_reset_postdata();

    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
}
endif;
// thumbnail section content details.
add_filter( 'greatnews_pro_filter_thumbnail_section_details', 'greatnews_pro_get_thumbnail_section_details' );


if ( ! function_exists( 'greatnews_pro_render_thumbnail_section' ) ) :
/**
* Start thumbnail section
*
* @return string thumbnail content
* @since Greatnews Pro 1.0.0
*
*/
function greatnews_pro_render_thumbnail_section( $content_details = array() ) {
    $options = greatnews_pro_get_theme_options();
    $thumbnail_content_type  = $options['thumbnail_content_type'];

    if ( empty( $content_details ) ) {
        return;
    } ?>
    <div id="thumbnail-post">
        <div class="wrapper">
            <div class="thumbnail-wrapper col-4">
                <div class="thumbnail-post-wrapper">
                    <?php foreach ( $content_details as $content ) : ?>

                        <article>
                            <div class="featured-image">
                                <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                            
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-meta">
                                    <?php  greatnews_pro_posted_on( $content['id'] ); ?>
                                </div><!-- .entry-meta -->
                            </div><!-- .entry-container -->
                        </article>

                    <?php endforeach; ?>
                </div>
            </div><!-- .thumbnail --> 
        </div><!-- .wrapper -->
    </div><!-- #thumbnail-posts -->

    <?php }
    endif;